@@ -10,7 +10,20 @@ real_date = datetime.date
 real_datetime = datetime.datetime
 
 
-class FakeDate(real_date):
+# Stolen from six
+def with_metaclass(meta, *bases):
+    """Create a base class with a metaclass."""
+    return meta("NewBase", bases, {})
+
+
+class FakeDateMeta(type):
+    @classmethod
+    def __instancecheck__(self, obj):
+        return isinstance(obj, real_date)
+
+
+class FakeDate(with_metaclass(FakeDateMeta, real_date)):
+
     date_to_freeze = None
 
     def __new__(cls, *args, **kwargs):
@@ -187,7 +200,7 @@ def freeze_time(time_to_freeze, tz_offset=0):
         string_type = str
 
     if not isinstance(time_to_freeze, string_type):
-        raise TypeError(('freeze_time() expected a string '
-                         'but got type %s.') % type(time_to_freeze))
+        raise TypeError(('freeze_time() expected a string, date instance, or '
+                         'datetime instance, but got type {0}.').format(type(time_to_freeze)))
 
     return _freeze_time(time_to_freeze, tz_offset)
